@@ -1,6 +1,6 @@
 .First.lib <- function(lib,pkg) {
-  require(survival)
-  require(prodlim)
+  ## require(survival)
+  ## require(prodlim)
   library.dynam("pec",pkg,lib)
 }
 .Last.lib <- function(lib)
